@@ -15,27 +15,27 @@ import sys
 from typing import Any, Dict, List
 
 from .literals import (
-    AccountScope,
-    AnomalyFeedbackType,
-    AnomalySubscriptionFrequency,
-    CostCategoryInheritedValueDimensionName,
-    CostCategoryRuleType,
-    CostCategoryStatus,
-    Dimension,
-    GroupDefinitionType,
-    LookbackPeriodInDays,
-    MatchOption,
-    MonitorType,
-    NumericOperator,
-    OfferingClass,
-    PaymentOption,
-    RecommendationTarget,
-    RightsizingType,
-    SortOrder,
-    SubscriberStatus,
-    SubscriberType,
-    SupportedSavingsPlansType,
-    TermInYears,
+    AccountScopeType,
+    AnomalyFeedbackTypeType,
+    AnomalySubscriptionFrequencyType,
+    CostCategoryInheritedValueDimensionNameType,
+    CostCategoryRuleTypeType,
+    CostCategoryStatusType,
+    DimensionType,
+    GroupDefinitionTypeType,
+    LookbackPeriodInDaysType,
+    MatchOptionType,
+    MonitorTypeType,
+    NumericOperatorType,
+    OfferingClassType,
+    PaymentOptionType,
+    RecommendationTargetType,
+    RightsizingTypeType,
+    SortOrderType,
+    SubscriberStatusType,
+    SubscriberTypeType,
+    SupportedSavingsPlansTypeType,
+    TermInYearsType,
 )
 
 if sys.version_info >= (3, 8):
@@ -177,7 +177,7 @@ _RequiredAnomalyMonitorTypeDef = TypedDict(
     "_RequiredAnomalyMonitorTypeDef",
     {
         "MonitorName": str,
-        "MonitorType": MonitorType,
+        "MonitorType": MonitorTypeType,
     },
 )
 _OptionalAnomalyMonitorTypeDef = TypedDict(
@@ -213,7 +213,7 @@ _RequiredAnomalySubscriptionTypeDef = TypedDict(
         "MonitorArnList": List[str],
         "Subscribers": List["SubscriberTypeDef"],
         "Threshold": float,
-        "Frequency": AnomalySubscriptionFrequency,
+        "Frequency": AnomalySubscriptionFrequencyType,
         "SubscriptionName": str,
     },
 )
@@ -249,7 +249,7 @@ _OptionalAnomalyTypeDef = TypedDict(
         "AnomalyEndDate": str,
         "DimensionValue": str,
         "RootCauses": List["RootCauseTypeDef"],
-        "Feedback": AnomalyFeedbackType,
+        "Feedback": AnomalyFeedbackTypeType,
     },
     total=False,
 )
@@ -262,7 +262,7 @@ class AnomalyTypeDef(_RequiredAnomalyTypeDef, _OptionalAnomalyTypeDef):
 CostCategoryInheritedValueDimensionTypeDef = TypedDict(
     "CostCategoryInheritedValueDimensionTypeDef",
     {
-        "DimensionName": CostCategoryInheritedValueDimensionName,
+        "DimensionName": CostCategoryInheritedValueDimensionNameType,
         "DimensionKey": str,
     },
     total=False,
@@ -272,7 +272,7 @@ CostCategoryProcessingStatusTypeDef = TypedDict(
     "CostCategoryProcessingStatusTypeDef",
     {
         "Component": Literal["COST_EXPLORER"],
-        "Status": CostCategoryStatus,
+        "Status": CostCategoryStatusType,
     },
     total=False,
 )
@@ -298,7 +298,7 @@ CostCategoryRuleTypeDef = TypedDict(
         "Value": str,
         "Rule": "ExpressionTypeDef",
         "InheritedValue": "CostCategoryInheritedValueDimensionTypeDef",
-        "Type": CostCategoryRuleType,
+        "Type": CostCategoryRuleTypeType,
     },
     total=False,
 )
@@ -333,7 +333,7 @@ CostCategoryValuesTypeDef = TypedDict(
     {
         "Key": str,
         "Values": List[str],
-        "MatchOptions": List[MatchOption],
+        "MatchOptions": List[MatchOptionType],
     },
     total=False,
 )
@@ -457,9 +457,9 @@ DescribeCostCategoryDefinitionResponseTypeDef = TypedDict(
 DimensionValuesTypeDef = TypedDict(
     "DimensionValuesTypeDef",
     {
-        "Key": Dimension,
+        "Key": DimensionType,
         "Values": List[str],
-        "MatchOptions": List[MatchOption],
+        "MatchOptions": List[MatchOptionType],
     },
     total=False,
 )
@@ -529,7 +529,7 @@ EC2ResourceUtilizationTypeDef = TypedDict(
 EC2SpecificationTypeDef = TypedDict(
     "EC2SpecificationTypeDef",
     {
-        "OfferingClass": OfferingClass,
+        "OfferingClass": OfferingClassType,
     },
     total=False,
 )
@@ -901,7 +901,7 @@ GetUsageForecastResponseTypeDef = TypedDict(
 GroupDefinitionTypeDef = TypedDict(
     "GroupDefinitionTypeDef",
     {
-        "Type": GroupDefinitionType,
+        "Type": GroupDefinitionTypeType,
         "Key": str,
     },
     total=False,
@@ -1089,10 +1089,10 @@ ReservationPurchaseRecommendationSummaryTypeDef = TypedDict(
 ReservationPurchaseRecommendationTypeDef = TypedDict(
     "ReservationPurchaseRecommendationTypeDef",
     {
-        "AccountScope": AccountScope,
-        "LookbackPeriodInDays": LookbackPeriodInDays,
-        "TermInYears": TermInYears,
-        "PaymentOption": PaymentOption,
+        "AccountScope": AccountScopeType,
+        "LookbackPeriodInDays": LookbackPeriodInDaysType,
+        "TermInYears": TermInYearsType,
+        "PaymentOption": PaymentOptionType,
         "ServiceSpecification": "ServiceSpecificationTypeDef",
         "RecommendationDetails": List["ReservationPurchaseRecommendationDetailTypeDef"],
         "RecommendationSummary": "ReservationPurchaseRecommendationSummaryTypeDef",
@@ -1141,7 +1141,7 @@ ResultByTimeTypeDef = TypedDict(
 RightsizingRecommendationConfigurationTypeDef = TypedDict(
     "RightsizingRecommendationConfigurationTypeDef",
     {
-        "RecommendationTarget": RecommendationTarget,
+        "RecommendationTarget": RecommendationTargetType,
         "BenefitsConsidered": bool,
     },
 )
@@ -1151,7 +1151,7 @@ RightsizingRecommendationMetadataTypeDef = TypedDict(
     {
         "RecommendationId": str,
         "GenerationTimestamp": str,
-        "LookbackPeriodInDays": LookbackPeriodInDays,
+        "LookbackPeriodInDays": LookbackPeriodInDaysType,
         "AdditionalMetadata": str,
     },
     total=False,
@@ -1173,7 +1173,7 @@ RightsizingRecommendationTypeDef = TypedDict(
     {
         "AccountId": str,
         "CurrentInstance": "CurrentInstanceTypeDef",
-        "RightsizingType": RightsizingType,
+        "RightsizingType": RightsizingTypeType,
         "ModifyRecommendationDetail": "ModifyRecommendationDetailTypeDef",
         "TerminateRecommendationDetail": "TerminateRecommendationDetailTypeDef",
     },
@@ -1286,11 +1286,11 @@ SavingsPlansPurchaseRecommendationSummaryTypeDef = TypedDict(
 SavingsPlansPurchaseRecommendationTypeDef = TypedDict(
     "SavingsPlansPurchaseRecommendationTypeDef",
     {
-        "AccountScope": AccountScope,
-        "SavingsPlansType": SupportedSavingsPlansType,
-        "TermInYears": TermInYears,
-        "PaymentOption": PaymentOption,
-        "LookbackPeriodInDays": LookbackPeriodInDays,
+        "AccountScope": AccountScopeType,
+        "SavingsPlansType": SupportedSavingsPlansTypeType,
+        "TermInYears": TermInYearsType,
+        "PaymentOption": PaymentOptionType,
+        "LookbackPeriodInDays": LookbackPeriodInDaysType,
         "SavingsPlansPurchaseRecommendationDetails": List[
             "SavingsPlansPurchaseRecommendationDetailTypeDef"
         ],
@@ -1394,7 +1394,7 @@ _RequiredSortDefinitionTypeDef = TypedDict(
 _OptionalSortDefinitionTypeDef = TypedDict(
     "_OptionalSortDefinitionTypeDef",
     {
-        "SortOrder": SortOrder,
+        "SortOrder": SortOrderType,
     },
     total=False,
 )
@@ -1408,8 +1408,8 @@ SubscriberTypeDef = TypedDict(
     "SubscriberTypeDef",
     {
         "Address": str,
-        "Type": SubscriberType,
-        "Status": SubscriberStatus,
+        "Type": SubscriberTypeType,
+        "Status": SubscriberStatusType,
     },
     total=False,
 )
@@ -1419,7 +1419,7 @@ TagValuesTypeDef = TypedDict(
     {
         "Key": str,
         "Values": List[str],
-        "MatchOptions": List[MatchOption],
+        "MatchOptions": List[MatchOptionType],
     },
     total=False,
 )
@@ -1449,7 +1449,7 @@ TerminateRecommendationDetailTypeDef = TypedDict(
 _RequiredTotalImpactFilterTypeDef = TypedDict(
     "_RequiredTotalImpactFilterTypeDef",
     {
-        "NumericOperator": NumericOperator,
+        "NumericOperator": NumericOperatorType,
         "StartValue": float,
     },
 )
